==> f-spot-0.1.0.tar.gz: f-spot-0.1.0/src/Global.cs <==
namespace FSpot {
	public class Global {
		public static string HomeDirectory {
			get {
				return System.IO.Path.Combine (System.Environment.GetEnvironmentVariable ("HOME"), "");	
			}
		}

		public static string BaseDirectory {
			get {
				return System.IO.Path.Combine (HomeDirectory,  System.IO.Path.Combine (".gnome2", "f-spot"));
			}
		}

		public static string PhotoDirectory {
			get {
				return System.IO.Path.Combine (HomeDirectory, "Photos");
			}
		}

		public static void ModifyColors (Gtk.Widget widget)
		{
#if false
			Gdk.Color color = widget.Style.Background (Gtk.StateType.Normal);
			color.Red = (ushort) (color.Red / 2);
			color.Blue = (ushort) (color.Blue / 2);
			color.Green = (ushort) (color.Green / 2);
			widget.ModifyBg (Gtk.StateType.Normal, color);
#else 
			try {
				widget.ModifyFg (Gtk.StateType.Normal, widget.Style.TextColors [(int)Gtk.StateType.Normal]);
				widget.ModifyBg (Gtk.StateType.Normal, widget.Style.BaseColors [(int)Gtk.StateType.Normal]);
			} catch {
				widget.ModifyFg (Gtk.StateType.Normal, widget.Style.Black);
				widget.ModifyBg (Gtk.StateType.Normal, widget.Style.White);
			}
#endif 
		}

#if false
		private Cms.Profile display_profile;
		public Cms.Profile DisplayProfile {
			get {
				return Cms.Profile.CreateSRgb ();
			}
		}
		
		private System.Collections.Hashtable profile_cache;
		public Cms.Transform DisplayTranform (Cms.Profile image_profile)
		{
			if (image_profile == null && display_profile == null)
				return null;
		}
#endif

	}
}

==> f-spot_0.1.11.orig.tar.gz: f-spot-0.1.11/src/Global.cs <==
namespace FSpot {
	public class Global {
		public static string HomeDirectory {
			get {
				return System.IO.Path.Combine (System.Environment.GetEnvironmentVariable ("HOME"), "");	
			}
		}

		public static string BaseDirectory {
			get {
				return System.IO.Path.Combine (HomeDirectory,  System.IO.Path.Combine (".gnome2", "f-spot"));
			}
		}

		public static string PhotoDirectory {
			get {
				return System.IO.Path.Combine (HomeDirectory, "Photos");
			}
		}
		
		public static void ModifyColors (Gtk.Widget widget)
		{
#if false
			Gdk.Color color = widget.Style.Background (Gtk.StateType.Normal);
			color.Red = (ushort) (color.Red / 2);
			color.Blue = (ushort) (color.Blue / 2);
			color.Green = (ushort) (color.Green / 2);
			widget.ModifyBg (Gtk.StateType.Normal, color);
#else 
			try {
				widget.ModifyFg (Gtk.StateType.Normal, widget.Style.TextColors [(int)Gtk.StateType.Normal]);
				widget.ModifyBg (Gtk.StateType.Normal, widget.Style.BaseColors [(int)Gtk.StateType.Normal]);
			} catch {
				widget.ModifyFg (Gtk.StateType.Normal, widget.Style.Black);
				widget.ModifyBg (Gtk.StateType.Normal, widget.Style.White);
			}
#endif 
		}

		private static Cms.Profile display_profile;
		public static Cms.Profile DisplayProfile {
			set { display_profile = value; }
			get { return display_profile; }
		}

		private static Cms.Profile destination_profile;
		public static Cms.Profile DestinationProfile {
			set { destination_profile = value; }
			get { return destination_profile; }
		}
	}
}
